@@ -80,7 +80,8 @@ class PolySerial (threading.Thread):
 
     def __del__(self):
         self.close()
-        threading.Thread.__del__(self)
+        self.join()     #stop thread
+
 
     def close(self):
         if self.opened:
@@ -291,6 +292,10 @@ class PolyPacket:
 
         #dont respond to acks
         if self.ackFlag:
+            if self.desc.name in iface.service.handlers:
+                iface.service.handlers[self.desc.name](iface.service,self,None )
+            elif 'default' in iface.service.handlers:
+                iface.service.handlers['default'](iface.service, self,None)
             return 0
 
         if not iface.service.autoAck:
